@@ -7,6 +7,7 @@ import socket
 import random
 import time
 import sys
+import os
 
 LEVEL_MAP = {"warn": 2, "info": 3, "debug": 4, "trace": 5}
 
@@ -33,39 +34,40 @@ def listen(my_ip):
     sock.bind((UDP_IP, UDP_PORT))
     return sock, UDP_PORT
 
+
 def auto_int(string: str) -> int:
     """Attempts to automatically detect the base of the input string and parse it as
        an int"""
     return int(string, 0)
 
+
 class LivelogCommand(BaseCommand):
     subcmd = "livelog"
     help = "Start streaming logs"
-    arguments = [
-        (["--ip"], {"help": "IP of log server"}),
-        (["--port"], {"help": "UDP port of log server"}),
-        (
-            ["--level"],
-            {
-                "help": "set the verbosity: warn, info, debug (may slow the Bond), or trace (will make the bond unuseably slow, it's recommended to only use this in subys-level)",
-                "choices": LEVEL_MAP.keys(),
-            },
-        ),
-        (["--subsys"], {"help": "the subsys target to change the log level for", "type": auto_int}),
-        (
-            ["--subsys-level"],
-            {
-                "help": "set the verbosity for the given subsys: warn, info, debug, or trace",
-                "choices": LEVEL_MAP.keys(),
-            },
-        ),
-    ]
+    arguments = {
+        "--ip": {"help": "IP of log server"},
+        "--port": {"help": "UDP port of log server"},
+        "--level": {
+            "help": "set the verbosity: warn, info, debug (may slow the Bond), or trace (will make the bond unuseably slow, it's recommended to only use this in subys-level)",
+            "choices": LEVEL_MAP.keys(),
+        },
+        "--subsys": {
+            "help": "the subsys target to change the log level for",
+            "type": auto_int,
+        },
+        "--subsys-level": {
+            "help": "set the verbosity for the given subsys: warn, info, debug, or trace",
+            "choices": LEVEL_MAP.keys(),
+        },
+        "--out": {
+            "help": "a filename to write the logs to",
+            "default": os.devnull,
+        }
+    }
 
     def run(self, args):
         bondid = BondDatabase.get_assert_selected_bondid()
 
-        log_fn = bondid + ".livelog"
-
         if args.level:
             bond.proto.patch(
                 bondid, topic="debug/syslog", body={"lvl": LEVEL_MAP[args.level]}
@@ -74,13 +76,10 @@ class LivelogCommand(BaseCommand):
             body = {"subsys": args.subsys}
             if args.subsys_level:
                 body["lvl"] = LEVEL_MAP[args.subsys_level]
-            bond.proto.patch(
-                bondid, topic="debug/syslog", body=body,
-            )
-
+            bond.proto.patch(bondid, topic="debug/syslog", body=body)
 
         if args.ip is None:
-            with open(log_fn, "w+") as log:
+            with open(args.out, "w+") as log:
                 my_ip = get_my_ip(BondDatabase.get_bonds()[bondid]["ip"])
                 sock, UDP_PORT = listen(my_ip)
                 do_livelog(bondid, my_ip, UDP_PORT)
